@@ -12,6 +12,7 @@ from ordered_model.admin import OrderedInlineModelAdminMixin, OrderedTabularInli
 from obapi import utils
 from obapi.exceptions import APICallError
 from obapi.forms import (
+    AddEssayContentItemForm,
     AddOBContentItemForm,
     AddSpotifyContentItemForm,
     AddYoutubeContentItemForm,
@@ -33,6 +34,7 @@ from obapi.models import (
     YoutubeContentItem,
 )
 from obapi.models.classifiers import CLASSIFIER_SLUG_MAX_LENGTH, ExternalLink
+from obapi.models.content import EssayContentItem
 
 # Inlines
 # https://docs.djangoproject.com/en/4.0/ref/contrib/admin/#inlinemodeladmin-objects
@@ -447,17 +449,15 @@ class OBContentItemAdmin(ContentItemAdminTemplate):
         return changecount
 
 
+@admin.register(EssayContentItem)
+class EssayContentItemAdmin(ContentItemAdminTemplate):
+    AddForm = AddEssayContentItemForm
+
+
 class SequenceMemberInline(OrderedTabularInline):
     model = SequenceMember
-    fields = (
-        "content_item",
-        "order",
-        "move_up_down_links",
-    )
-    readonly_fields = (
-        "order",
-        "move_up_down_links",
-    )
+    fields = ("content_item", "order", "move_up_down_links")
+    readonly_fields = ("order", "move_up_down_links")
     ordering = ("order",)
     extra = 1
     autocomplete_fields = ("content_item",)
@@ -468,3 +468,4 @@ class SequenceAdmin(OrderedInlineModelAdminMixin, admin.ModelAdmin):
     model = Sequence
     list_display = ("title",)
     inlines = (SequenceMemberInline,)
+    readonly_fields = ("create_timestamp", "update_timestamp")
